==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/SUPPLIERFUELMIXID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour SUPPLIERFUELMIXID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="SUPPLIERFUELMIXID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SUPPLIERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COMMODITYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEEFFECTIVE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TYPE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SUPPLIERFUELMIXID_Type", propOrder = {
    "supplierid",
    "commodityid",
    "dateeffective",
    "type"
})
public class SUPPLIERFUELMIXID_Type {

    @XmlElement(name = "SUPPLIERID", required = true)
    protected SUPPLIERID_Type supplierid;
    @XmlElement(name = "COMMODITYID", required = true)
    protected COMMODITY_Type commodityid;
    @XmlElement(name = "DATEEFFECTIVE", required = true)
    protected DATETIME dateeffective;
    @XmlElement(name = "TYPE", required = true)
    protected TYPE_Type type;

    /**
     * Obtient la valeur de la propriété supplierid.
     * 
     * @return
     *     possible object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public SUPPLIERID_Type getSUPPLIERID() {
        return supplierid;
    }

    /**
     * Définit la valeur de la propriété supplierid.
     * 
     * @param value
     *     allowed object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public void setSUPPLIERID(SUPPLIERID_Type value) {
        this.supplierid = value;
    }

    /**
     * Obtient la valeur de la propriété commodityid.
     * 
     * @return
     *     possible object is
     *     {@link COMMODITY_Type }
     *     
     */
    public COMMODITY_Type getCOMMODITYID() {
        return commodityid;
    }

    /**
     * Définit la valeur de la propriété commodityid.
     * 
     * @param value
     *     allowed object is
     *     {@link COMMODITY_Type }
     *     
     */
    public void setCOMMODITYID(COMMODITY_Type value) {
        this.commodityid = value;
    }

    /**
     * Obtient la valeur de la propriété dateeffective.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEEFFECTIVE() {
        return dateeffective;
    }

    /**
     * Définit la valeur de la propriété dateeffective.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEEFFECTIVE(DATETIME value) {
        this.dateeffective = value;
    }

    /**
     * Obtient la valeur de la propriété type.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getTYPE() {
        return type;
    }

    /**
     * Définit la valeur de la propriété type.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setTYPE(TYPE_Type value) {
        this.type = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/SUPPLIERFUELMIXID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for SUPPLIERFUELMIXID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SUPPLIERFUELMIXID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SUPPLIERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COMMODITYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEEFFECTIVE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TYPE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SUPPLIERFUELMIXID_Type", propOrder = {
    "supplierid",
    "commodityid",
    "dateeffective",
    "type"
})
public class SUPPLIERFUELMIXID_Type {

    @XmlElement(name = "SUPPLIERID", required = true)
    protected SUPPLIERID_Type supplierid;
    @XmlElement(name = "COMMODITYID", required = true)
    protected COMMODITY_Type commodityid;
    @XmlElement(name = "DATEEFFECTIVE", required = true)
    protected DATETIME dateeffective;
    @XmlElement(name = "TYPE", required = true)
    protected TYPE_Type type;

    /**
     * Gets the value of the supplierid property.
     * 
     * @return
     *     possible object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public SUPPLIERID_Type getSUPPLIERID() {
        return supplierid;
    }

    /**
     * Sets the value of the supplierid property.
     * 
     * @param value
     *     allowed object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public void setSUPPLIERID(SUPPLIERID_Type value) {
        this.supplierid = value;
    }

    /**
     * Gets the value of the commodityid property.
     * 
     * @return
     *     possible object is
     *     {@link COMMODITY_Type }
     *     
     */
    public COMMODITY_Type getCOMMODITYID() {
        return commodityid;
    }

    /**
     * Sets the value of the commodityid property.
     * 
     * @param value
     *     allowed object is
     *     {@link COMMODITY_Type }
     *     
     */
    public void setCOMMODITYID(COMMODITY_Type value) {
        this.commodityid = value;
    }

    /**
     * Gets the value of the dateeffective property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEEFFECTIVE() {
        return dateeffective;
    }

    /**
     * Sets the value of the dateeffective property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEEFFECTIVE(DATETIME value) {
        this.dateeffective = value;
    }

    /**
     * Gets the value of the type property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getTYPE() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setTYPE(TYPE_Type value) {
        this.type = value;
    }

}
